==> astro-0.0.3.tgz: package/lib/config.js <==
import { join as pathJoin, resolve as pathResolve } from 'path';
import { existsSync } from 'fs';
/** Type util */
const type = (thing) => (Array.isArray(thing) ? 'Array' : typeof thing);
/** Throws error if a user provided an invalid config. Manually-implemented to avoid a heavy validation library. */
function validateConfig(config) {
    // basic
    if (config === undefined || config === null)
        throw new Error(`[astro config] Config empty!`);
    if (typeof config !== 'object')
        throw new Error(`[astro config] Expected object, received ${typeof config}`);
    // strings
    for (const key of ['projectRoot', 'astroRoot', 'dist', 'public']) {
        if (config[key] && typeof config[key] !== 'string') {
            throw new Error(`[astro config] ${key}: ${JSON.stringify(config[key])}\n  Expected string, received ${type(config[key])}.`);
        }
    }
}
/** Set default config values */
function configDefaults(userConfig) {
    const config = { ...(userConfig || {}) };
    if (!config.projectRoot)
        config.projectRoot = '.';
    if (!config.astroRoot)
        config.astroRoot = './astro';
    if (!config.dist)
        config.dist = './_site';
    if (!config.public)
        config.public = './public';
    return config;
}
/** Turn raw config values into normalized values */
function normalizeConfig(userConfig, root) {
    const config = { ...(userConfig || {}) };
    const fileProtocolRoot = `file://${root}/`;
    config.projectRoot = new URL(config.projectRoot + '/', fileProtocolRoot);
    config.astroRoot = new URL(config.astroRoot + '/', fileProtocolRoot);
    config.public = new URL(config.public + '/', fileProtocolRoot);
    return config;
}
/** Attempt to load an `astro.config.mjs` file */
export async function loadConfig(rawRoot) {
    if (typeof rawRoot === 'undefined') {
        rawRoot = process.cwd();
    }
    const root = pathResolve(rawRoot);
    const astroConfigPath = pathJoin(root, 'astro.config.mjs');
    // load
    let config;
    if (existsSync(astroConfigPath)) {
        config = configDefaults((await import(astroConfigPath)).default);
    }
    else {
        config = configDefaults();
    }
    // validate
    validateConfig(config);
    // normalize
    config = normalizeConfig(config, root);
    return config;
}

==> astro-0.0.7.tgz: package/lib/config.js <==
import { join as pathJoin, resolve as pathResolve } from 'path';
import { existsSync } from 'fs';
/** Type util */
const type = (thing) => (Array.isArray(thing) ? 'Array' : typeof thing);
/** Throws error if a user provided an invalid config. Manually-implemented to avoid a heavy validation library. */
function validateConfig(config) {
    // basic
    if (config === undefined || config === null)
        throw new Error(`[astro config] Config empty!`);
    if (typeof config !== 'object')
        throw new Error(`[astro config] Expected object, received ${typeof config}`);
    // strings
    for (const key of ['projectRoot', 'astroRoot', 'dist', 'public', 'site']) {
        if (config[key] !== undefined && config[key] !== null && typeof config[key] !== 'string') {
            throw new Error(`[astro config] ${key}: ${JSON.stringify(config[key])}\n  Expected string, received ${type(config[key])}.`);
        }
    }
    // booleans
    for (const key of ['sitemap']) {
        if (config[key] !== undefined && config[key] !== null && typeof config[key] !== 'boolean') {
            throw new Error(`[astro config] ${key}: ${JSON.stringify(config[key])}\n  Expected boolean, received ${type(config[key])}.`);
        }
    }
    if (typeof config.devOptions?.port !== 'number') {
        throw new Error(`[astro config] devOptions.port: Expected number, received ${type(config.devOptions?.port)}`);
    }
}
/** Set default config values */
function configDefaults(userConfig) {
    const config = { ...(userConfig || {}) };
    if (!config.projectRoot)
        config.projectRoot = '.';
    if (!config.astroRoot)
        config.astroRoot = './astro';
    if (!config.dist)
        config.dist = './_site';
    if (!config.public)
        config.public = './public';
    if (!config.devOptions)
        config.devOptions = {};
    if (!config.devOptions.port)
        config.devOptions.port = 3000;
    if (!config.buildOptions)
        config.buildOptions = {};
    if (typeof config.buildOptions.sitemap === 'undefined')
        config.buildOptions.sitemap = true;
    return config;
}
/** Turn raw config values into normalized values */
function normalizeConfig(userConfig, root) {
    const config = { ...(userConfig || {}) };
    const fileProtocolRoot = `file://${root}/`;
    config.projectRoot = new URL(config.projectRoot + '/', fileProtocolRoot);
    config.astroRoot = new URL(config.astroRoot + '/', fileProtocolRoot);
    config.public = new URL(config.public + '/', fileProtocolRoot);
    return config;
}
/** Attempt to load an `astro.config.mjs` file */
export async function loadConfig(rawRoot, configFileName = 'astro.config.mjs') {
    if (typeof rawRoot === 'undefined') {
        rawRoot = process.cwd();
    }
    const root = pathResolve(rawRoot);
    const astroConfigPath = pathJoin(root, configFileName);
    // load
    let config;
    if (existsSync(astroConfigPath)) {
        config = configDefaults((await import(astroConfigPath)).default);
    }
    else {
        config = configDefaults();
    }
    // validate
    validateConfig(config);
    // normalize
    config = normalizeConfig(config, root);
    return config;
}
